@@ -5,11 +5,9 @@
 
 import time
 import board
-import busio
 from adafruit_ltr390 import LTR390, MeasurementDelay, Resolution, Gain
 
-i2c = busio.I2C(board.SCL, board.SDA)
-
+i2c = board.I2C()
 ltr = LTR390(i2c)
 
 # ltr.resolution = Resolution.RESOLUTION_16BIT
